v1

package
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 2, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package v1 provides types for identifying Kubernetes API resources by group, version, and kind without depending on k8s.io/apimachinery.

Portions of this package are adapted from the Kubernetes apimachinery project: https://github.com/kubernetes/apimachinery/blob/v0.34.9/pkg/runtime/schema/group_version.go

Copyright 2015 The Kubernetes Authors. SPDX-License-Identifier: Apache-2.0

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GroupKind

type GroupKind struct {
	Group string
	Kind  string
}

GroupKind specifies a Group and a Kind, but does not force a version. This is useful for identifying concepts during lookup stages without having partially valid types.

func ParseGroupKind

func ParseGroupKind(gk string) GroupKind

ParseGroupKind turns "Kind.group" string into a GroupKind struct.

func (GroupKind) Empty

func (gk GroupKind) Empty() bool

func (GroupKind) String

func (gk GroupKind) String() string

func (GroupKind) WithVersion

func (gk GroupKind) WithVersion(version string) GroupVersionKind

type GroupVersion

type GroupVersion struct {
	Group   string
	Version string
}

GroupVersion contains the "group" and the "version", which uniquely identifies the API.

func ParseGroupVersion

func ParseGroupVersion(gv string) (GroupVersion, error)

ParseGroupVersion turns "group/version" string into a GroupVersion struct. It reports error if it cannot parse the string.

func (GroupVersion) Empty

func (gv GroupVersion) Empty() bool

Empty returns true if group and version are empty.

func (GroupVersion) String

func (gv GroupVersion) String() string

String puts "group" and "version" into a single "group/version" string. For the legacy v1 it returns "v1".

func (GroupVersion) WithKind

func (gv GroupVersion) WithKind(kind string) GroupVersionKind

WithKind creates a GroupVersionKind based on the method receiver's GroupVersion and the passed Kind.

type GroupVersionKind

type GroupVersionKind struct {
	Group   string
	Version string
	Kind    string
}

GroupVersionKind unambiguously identifies a kind. It doesn't anonymously include GroupVersion to avoid automatic coercion. It doesn't use a GroupVersion to avoid custom marshalling.

func FromAPIVersionAndKind

func FromAPIVersionAndKind(apiVersion, kind string) GroupVersionKind

FromAPIVersionAndKind returns a GVK representing the provided fields for types that do not use TypeMeta. This method exists to support test types and legacy serializations that have a distinct group and kind.

func (GroupVersionKind) Empty

func (gvk GroupVersionKind) Empty() bool

Empty returns true if group, version, and kind are empty.

func (GroupVersionKind) GroupKind

func (gvk GroupVersionKind) GroupKind() GroupKind

func (GroupVersionKind) GroupVersion

func (gvk GroupVersionKind) GroupVersion() GroupVersion

func (GroupVersionKind) String

func (gvk GroupVersionKind) String() string

func (GroupVersionKind) ToAPIVersionAndKind

func (gvk GroupVersionKind) ToAPIVersionAndKind() (string, string)

ToAPIVersionAndKind is a convenience method for satisfying runtime.Object on types that do not use TypeMeta.

Jump to